SideMenuStyle class

Constructors

SideMenuStyle({double fontSize = 0, double? iconSize = 18, double? menuWidth = 250, double itemHeight = 40, bool divider = true, bool rightBorder = true, Color itemSelectBGColor = const Color.fromRGBO(46, 173, 250, 0.3), Color dividerColor = const Color.fromRGBO(153, 153, 153, 0.3), Color itemSelectColor = Colors.white, Color itemUnselectColor = Colors.black, Color itemUnselectBGColor = Colors.white})
SideMenuStyle.fromJson(Map<String, dynamic> json)
factory

Properties

divider bool
getter/setter pair
dividerColor Color
getter/setter pair
fontSize double
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
iconSize double?
getter/setter pair
itemHeight double
getter/setter pair
itemSelectBGColor Color
getter/setter pair
itemSelectColor Color
getter/setter pair
itemUnselectBGColor Color
getter/setter pair
itemUnselectColor Color
getter/setter pair
getter/setter pair
rightBorder bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toPrettyJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited